function e1gx(priklad,metoda,srovnej,tisk)
%% Godunovova metoda pro Eulerovy rovnice v 1D :: ridici program
%
% Vstupni udaje:
%
% priklad ... cislo prikladu [E. Toro dodal vstupy pro priklady 1-5]
% metoda  ... cislo metody = 1, Roe
%                          = 2, HLLC
%                          = 3, HLL
%                          = 4, Rusakov
%                          = 5, Vijayasundaram
%                          = 6, Steger-Warming
%                          = 7, van Leer (podle Faistauera)
%                          = 8, van Leer (podle Tora)
% srovnej ... = 0, bez srovnani s presnym resenim Riemannovy ulohy
%             = 1, provede se srovnani s presnym resenim Riemannovy ulohy 
% tisk    ... = 0, bez pomocnych tisku
%             = 1, s pomocnymi tisky
%
% vstupni data se nacitaji ze souboru e1rpex##.ini, 
% kde ## je cislo prikladu:: 00,01,02,...,99
% ## = 00 ==> shock tube problem
%
% Vzorove volani :   e1gx(0,1,1,1); % priklad 0, metoda Roe, srovnani ano,
%                                     tisk ano
%% vstupni data
clc;
met=char('Roe','HLLC','HLL','Rusanov',...
         'Vijayasundaram', 'Steger-Warming',...
         'Van Leer (Faistauer)','Van Leer (Toro)');
if (metoda < 1) || (metoda > 8)
  error('Chybne zadana metoda');
end;
if srovnej==0, ss='ne'; else ss='ano'; end;
fprintf(['Numericke reseni Eulerovych rovnic v jedne dimenzi\n'...
         'metoda  : %s\n',...
         'priklad : %2d\n',...
         'srovnani s Riemannovym solverem : %s'],...
         deblank(met(metoda,:)),priklad,ss);
priklad=sprintf('%02d',priklad);     
% cteni vstupniho souboru
fid=fopen(['e1godf',priklad,'.ini'],'rt');
if fid < 0
  fprintf('\n');
  error('soubor %s neexistuje',['e1godf',priklad,'.ini']);
end;
tline=fgetl(fid); DOMLEN=sscanf(tline,'%e',1);
tline=fgetl(fid); DIAPH1=sscanf(tline,'%e',1);
tline=fgetl(fid); CELLS=sscanf(tline,'%d',1);
tline=fgetl(fid); GAMMA=sscanf(tline,'%e',1);
tline=fgetl(fid); TIMEOU=sscanf(tline,'%e',1);
tline=fgetl(fid); DLINIT=sscanf(tline,'%e',1);
tline=fgetl(fid); ULINIT=sscanf(tline,'%e',1);
tline=fgetl(fid); PLINIT=sscanf(tline,'%e',1);
tline=fgetl(fid); DMINIT=sscanf(tline,'%e',1);
tline=fgetl(fid); UMINIT=sscanf(tline,'%e',1);
tline=fgetl(fid); PMINIT=sscanf(tline,'%e',1);
tline=fgetl(fid); DRINIT=sscanf(tline,'%e',1);
tline=fgetl(fid); URINIT=sscanf(tline,'%e',1);
tline=fgetl(fid); PRINIT=sscanf(tline,'%e',1);
tline=fgetl(fid); DIAPH2=sscanf(tline,'%e',1);
tline=fgetl(fid); CFLCOE=sscanf(tline,'%e',1);
tline=fgetl(fid); IBCLEF=sscanf(tline,'%d',1);
tline=fgetl(fid); IBCRIG=sscanf(tline,'%d',1);
tline=fgetl(fid); NFREQU=sscanf(tline,'%d',1);
tline=fgetl(fid); NTMAXI=sscanf(tline,'%d',1);
tline=fgetl(fid); PSCALE=sscanf(tline,'%e',1);
fclose(fid);
INTFLX=metoda;
fprintf('\n**************************************************\n');
fprintf('delka intervalu          : %10.2f\n',DOMLEN);
fprintf('pocet bunek              : %10d\n',CELLS);
fprintf('cas                      : %10.4f\n',TIMEOU);
fprintf('poloha prepazky 1        : %10.2f\n',DIAPH1);
fprintf('poloha prepazky 2        : %10.2f\n',DIAPH2);
fprintf('hustota vlevo            : %10.4f    ',DLINIT);
fprintf('uprostred  : %10.4f    ',DMINIT); 
fprintf('vpravo   : %10.4f\n',DRINIT);
fprintf('rychlost vlevo           : %10.2f    ',ULINIT);
fprintf('uprostred  : %10.2f    ',UMINIT);
fprintf('vpravo   : %10.2f\n',URINIT);
fprintf('tlak vlevo               : %10.2f    ',PLINIT);
fprintf('uprostred  : %10.2f    ',PMINIT);
fprintf('vpravo   : %10.2f\n',PRINIT);
fprintf('konstanta CFL            : %10.2f\n',CFLCOE);
fprintf('okrajova podminka vlevo  : %10d\n',IBCLEF);
fprintf('okrajova podminka vpravo : %10d\n',IBCRIG);
fprintf('frekvence vystupu        : %10d\n',NFREQU);
fprintf('max. pocet kroku         : %10d\n',NTMAXI);
fprintf('koef. normalizace tlaku  : %10.2f\n',PSCALE);
%% vypocet
Xin={DOMLEN,DIAPH1,CELLS,GAMMA,TIMEOU,...
     DLINIT,ULINIT,PLINIT,DMINIT,UMINIT,PMINIT,DRINIT,URINIT,PRINIT,...
     DIAPH2,CFLCOE,IBCLEF,IBCRIG,NFREQU,NTMAXI,PSCALE,INTFLX};
[X,S]=e1g(Xin,tisk); 
%% tisk vysledku
if ~S
  fprintf(['\n***** metoda %s pro priklad %s',...
           ' selhala: [problem v : %s] *****\n'],...
           deblank(met(metoda,:)),priklad,S{2});
  return;
end;

if srovnej % reseni 1D Eulerovy ulohy  
  if tisk
    fprintf('pocita se presne reseni Eulerovych rovnic\n');  
  end
  Xin={DOMLEN,DIAPH1,1000,GAMMA,TIMEOU,...
      DLINIT,ULINIT,PLINIT,DRINIT,URINIT,PRINIT,PSCALE};
  [XE,~]=e1r(Xin,tisk);
end

rx=0.1; rd=0.1; ru=0.1; rp=0.1; re=0.1;
xmin=min(X(1,:));xmax=max(X(1,:)); dx=xmax-xmin;
%close all;

figure(1); %clf;
%subplot(4,1,1);
%hold on;
dmin=min(X(2,:));dmax=max(X(2,:));
if srovnej
  plot(XE(1,:),XE(2,:),'b-',X(1,:),X(2,:),'.r');
  dmin=min(dmin,min(XE(2,:))); dmax=max(dmax,max(XE(2,:)));
  title(sprintf('Eulerova rovnice, hustota, cas = %6.2f, metoda %s',...
    TIMEOU,met(INTFLX,:)));
else
%  plot(X(1,:),X(2,:),'-b',X(1,:),X(2,:),'.r');
  plot(X(1,:),X(2,:),'.r');

  title(sprintf('Eulerova rovnice,  hustota, cas =  %8.4g',TIMEOU));
end;
dd=dmax-dmin;
axis([xmin-rx*dx,xmax+rx*dx,dmin-rd*dd,dmax+rd*dd]);
%grid on;
xlabel('souradnice x');
ylabel('hustota ro');
%figure(1);

figure(2); %clf;
%subplot(4,1,2);
%hold on;
umin=min(X(3,:));umax=max(X(3,:));
if srovnej
  plot(XE(1,:),XE(3,:),'b-',X(1,:),X(3,:),'.r');
  umin=min(umin,min(XE(3,:))); umax=max(umax,max(XE(3,:)));
  title(sprintf('Eulerova rovnice, rychlost, cas = %6.2f, metoda %s',...
    TIMEOU,met(INTFLX,:)));
else
%  plot(X(1,:),X(3,:),'-b',X(1,:),X(3,:),'.r');
  plot(X(1,:),X(2,:),'.r');
  title(sprintf('Eulerova rovnice,  rychlost, cas =  %8.4g',TIMEOU));
end;
du=umax-umin;
axis([xmin-rx*dx,xmax+rx*dx,umin-ru*du,umax+ru*du]);
%grid on;
xlabel('souradnice x');
ylabel('rychlost u');

figure(3); %clf;
%subplot(4,2,1);
%hold on;
pmin=min(X(4,:));pmax=max(X(4,:));
if srovnej
  plot(XE(1,:),XE(4,:),'b-',X(1,:),X(4,:),'.r');
  pmin=min(pmin,min(XE(4,:))); pmax=max(pmax,max(XE(4,:)));
  title(sprintf('Eulerova rovnice, tlak, cas = %6.2f, metoda %s',...
    TIMEOU,met(INTFLX,:)));
else
%  plot(X(1,:),X(4,:),'-b',X(1,:),X(4,:),'.r');
  plot(X(1,:),X(4,:),'.r');
  title(sprintf('Eulerova rovnice,  tlak, cas =  %8.4g',TIMEOU));
end;
pu=pmax-pmin;
axis([xmin-rx*dx,xmax+rx*dx,pmin-rp*pu,pmax+rp*pu]);
%grid on;
xlabel('souradnice x');
ylabel('tlak p');

figure(4); %clf;
%subplot(4,2,2);
%hold on;
emin=min(X(5,:));emax=max(X(5,:));
if srovnej
  plot(XE(1,:),XE(5,:),'b-',X(1,:),X(5,:),'.r');
  emin=min(emin,min(XE(5,:))); emax=max(emax,max(XE(5,:)));
  title(sprintf('Eulerova rovnice, vnitrni energie, cas = %6.2f, metoda %s',...
    TIMEOU,met(INTFLX,:)));
else
%  plot(X(1,:),X(5,:),'-b',X(1,:),X(5,:),'.r');
  plot(X(1,:),X(5,:),'.r');
  title(sprintf('Eulerova rovnice, vnitrni energie, cas = %6.2f, metoda %s',...
    TIMEOU,met(INTFLX,:)));
end;
eu=emax-emin;
axis([xmin-rx*dx,xmax+rx*dx,emin-re*eu,emax+re*eu]);
%grid on;
xlabel('souradnice x');
ylabel('vnitrni energie');

