function e1rx
%% Riemannuv problem pro Eulerovy rovnice v 1D:: ridici program
%
% vstupni data se nacitaji ze souboru *e1rpex##.ini, 
% kde ## je cislo prikladu:: 00,01,02,...,99
% ## = 00 ==> shock tube problem 
%
tisk=true;  %            = true  ==> pomocne tisky solveru
%tisk=false; %            = false ==> bez pomocnych tisku solveru
fprintf('Eulerova rovnice v jedne dimenzi\n');
cpp=input('Zadej cislo prikladu : '); % 
cp=sprintf('%02d',cpp);
clc;
fprintf('Eulerova rovnice v jedne dimenzi, priklad %d\n',cpp);
% cteni vstupniho souboru
fid=fopen(['e1rpex',cp,'.ini'],'rt');
if fid < 0
  error('soubor %s neexistuje',['e1rpex',cpp,'.ini']);
end;
tline=fgetl(fid); DOMLEN=sscanf(tline,'%e',1);
tline=fgetl(fid); DIAPH1=sscanf(tline,'%e',1);
tline=fgetl(fid); CELLS=sscanf(tline,'%d',1);
tline=fgetl(fid); GAMMA=sscanf(tline,'%e',1);
tline=fgetl(fid); TIMEOU=sscanf(tline,'%e',1);
tline=fgetl(fid); DL=sscanf(tline,'%e',1);
tline=fgetl(fid); UL=sscanf(tline,'%e',1);
tline=fgetl(fid); PL=sscanf(tline,'%e',1);
tline=fgetl(fid); DR=sscanf(tline,'%e',1);
tline=fgetl(fid); UR=sscanf(tline,'%e',1);
tline=fgetl(fid); PR=sscanf(tline,'%e',1);
tline=fgetl(fid); PSCALE=sscanf(tline,'%e',1);
fclose(fid);
fprintf('\nvstupni data:\n\n');
fprintf(['delka intervalu : %10.2f\n'...,
         'pocet bunek     : %10d\n'...
         'cas             : %10.4f\n'],DOMLEN,CELLS,TIMEOU);
fprintf('hustota vlevo   : %10.4f    ',DL);fprintf('hustota vpravo  : %10.4f\n',DR);
fprintf('rychlost vlevo  : %8.2f      ',UL);fprintf('rychlost vpravo : %8.2f\n',UR);
fprintf('tlak vlevo      : %8.2f      ',PL);fprintf('tlak vpravo     : %8.2f\n',PR);
%% reseni 1D Eulerovy ulohy
fprintf('\nvypocet:\n\n');
Xin={DOMLEN,DIAPH1,CELLS,GAMMA,TIMEOU,DL,UL,PL,DR,UR,PR,PSCALE};
try
  [X,S]=e1r(Xin,tisk); 
catch ME
  disp('*** metoda selhala ***')
  disp(ME) % vypis objektu typu MException popisujiciho vyjimku
  soubor=ME.stack.file;
  jmeno={ME.stack.name};
  radek={ME.stack.line};
  fprintf('soubor = %s\n',soubor);
  for i=1:length(jmeno)
    fprintf('funkce : %s, radek : %d\n',jmeno{i}, radek{i});
  end
end;
%% tisk vysledku
fprintf('\nvysledky:\n\n');
fprintf(['hustota leva ve star-oblasti           %12.4f\n',...
         'hustota prava ve star-oblasti          %12.4f\n',...
         'rychlost ve star-oblasti               %12.4f\n',...
         'tlak ve star-oblasti                   %12.4f\n\n'],S(1:4));
if S(5)==S(6) 
  fprintf('leva razova vlna        v case %4.2f    %12.4f\n',TIMEOU,DIAPH1+S(5)*TIMEOU);
else
  fprintf('celo leve vlny zredeni  v case %4.2f    %12.4f\n',TIMEOU,DIAPH1+S(5)*TIMEOU);
  fprintf('tyl leve vlny zredeni   v case %4.2f    %12.4f\n',TIMEOU,DIAPH1+S(6)*TIMEOU);
end
fprintf('kontaktni nespojitost   v case %4.2f    %12.4f\n',TIMEOU,DIAPH1+S(3)*TIMEOU);
if S(7)==S(8)
  fprintf('prava razova vlna       v case %4.2f    %12.4f\n',TIMEOU,DIAPH1+S(7)*TIMEOU);
else
  fprintf('tyl prave vlny zredeni v case %4.2f     %12.4f\n',TIMEOU,DIAPH1+S(7)*TIMEOU);
  fprintf('celo prave vlny zredeni  v case %4.2f   %12.4f\n',TIMEOU,DIAPH1+S(8)*TIMEOU);
end
%% vykresleni
rx=0.1; rd=0.1; ru=0.1; rp=0.1; re=0.1;
xmin=min(X(1,:));xmax=max(X(1,:)); dx=xmax-xmin;
close all;
%------------------------------------------
figure(1);
%subplot(4,1,1);
plot(X(1,:),X(2,:));
dmin=min(X(2,:));dmax=max(X(2,:)); dd=dmax-dmin;
axis([xmin-rx*dx,xmax+rx*dx,dmin-rd*dd,dmax+rd*dd]);
grid on;
xlabel('souradnice x');
ylabel('hustota \rho');
title(sprintf('Eulerova rovnice,  hustota pro cas %6.2f',TIMEOU));
hold off;
%------------------------------------------
figure(2);
%subplot(4,1,2);
plot(X(1,:),X(3,:));
umin=min(X(3,:));umax=max(X(3,:)); du=umax-umin;
axis([xmin-rx*dx,xmax+rx*dx,umin-ru*du,umax+ru*du]);
grid on;
xlabel('souradnice x');
ylabel('rychlost u');
title(sprintf('Eulerova rovnice,  rychlost pro cas %6.2f',TIMEOU));
hold off;
%------------------------------------------
figure(3);
%subplot(4,2,1);
plot(X(1,:),X(4,:));
pmin=min(X(4,:));pmax=max(X(4,:)); pu=pmax-pmin;
axis([xmin-rx*dx,xmax+rx*dx,pmin-rp*pu,pmax+rp*pu]);
grid on;
xlabel('souradnice x');
ylabel('tlak p');
title(sprintf('Eulerova rovnice,  tlak pro cas %6.2f',TIMEOU));
hold off;
%-------------------------------------------
figure(4);
%subplot(4,2,2);
plot(X(1,:),X(5,:));
emin=min(X(5,:));emax=max(X(5,:)); eu=emax-emin;
axis([xmin-rx*dx,xmax+rx*dx,emin-re*eu,emax+re*eu]);
grid on;
xlabel('souradnice x');
ylabel('vnitrni energie e');
title(sprintf('Eulerova rovnice,  vnitrni energie pro cas %6.2f',TIMEOU));
%--------------------------------------------
figure(gcf);
